ChiantiPy package
=================

Subpackages
-----------

.. toctree::

    ChiantiPy.Gui
    ChiantiPy.base
    ChiantiPy.core
    ChiantiPy.fortranformat
    ChiantiPy.model
    ChiantiPy.tests
    ChiantiPy.tools

Submodules
----------


ChiantiPy\.version module
-------------------------

.. automodule:: ChiantiPy.version
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ChiantiPy
    :members:
    :undoc-members:
    :show-inheritance:
